library documentation
=====================

..
    [shields-start]
.. pypi
.. image:: https://img.shields.io/pypi/v/rna.svg
    :target: https://pypi.python.org/pypi//rna
.. ci
.. image:: https://gitlab.com/dboe/rna/badges/master/pipeline.svg
    :target: https://gitlab.com/dboe/rna/-/pipelines/latest
.. latest release
.. image:: https://gitlab.com/dboe/rna/-/badges/release.svg
    :target: https://gitlab.com/dboe/rna/-/releases
.. coverage
.. image:: https://gitlab.com/dboe/rna/badges/master/coverage.svg
    :target: https://gitlab.com/dboe/rna/commits/master
.. docs
.. image:: https://img.shields.io/website-up-down-green-red/https/dboe.gitlab.io/rna.svg?label=docs
    :target: https://dboe.gitlab.io/rna
.. pre-commit
.. image:: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white
   :target: https://github.com/pre-commit/pre-commit
   :alt: pre-commit
..
    [shields-end]

Overview
--------

..
    [overview-start]

Basic and essential code building blocks of all pythons

..
    [overview-end]

Licensed under the ``MIT``

Resources
~~~~~~~~~

..
    [resources-start]

- Documentation: https://dboe.gitlab.io/rna
- Source code: https://gitlab.com/dboe/rna
- Bug reports: https://gitlab.com/dboe/rna/-/issues/

- Pypi: https://pypi.python.org/pypi/rna


..
    [resources-end]

Features
~~~~~~~~

..
    [features-start]

The following features should be highlighted:

* TODO

..
    [features-end]

Installation
~~~~~~~~~~~~

..
    [install-start]
    
.. code-block:: shell

    pip install rna

..
    [install-end]

Usage
~~~~~

..
    [usage-start]

To use 'rna' in a project use

.. code-block:: python

    import rna

..
    [usage-end]
